@@ -17,6 +17,7 @@ from assembly_payments.services.user import UserService
 from assembly_payments.services.virtual_account import VirtualAccountService
 from assembly_payments.services.wallet_account import WalletAccountService
 from assembly_payments.services.webhook import WebhookService
+from assembly_payments.services.transaction import TransactionService
 
 PROD_BASE_URL = "https://secure.api.promisepay.com"
 PROD_AUTH_URL = "https://au-0000.auth.assemblypay.com"
@@ -91,3 +92,4 @@ class AssemblyClient:
         self.callbacks = CallbackService(**kwargs)
         self.batch_transactions = BatchTransactionService(**kwargs)
         self.bpay_accounts = BPayAccountService(**kwargs)
+        self.transactions = TransactionService(**kwargs)
