@@ -1,6 +1,6 @@
 
 from assembly_payments.services.base import BaseService
-from assembly_payments.types import DirectDebitAuthority, DirectDebitAuthorityRequest
+from assembly_payments.types import DirectDebitAuthority, DirectDebitAuthorityRequest, DirectDebitAuthorityFilters
 
 
 class DirectDebitAuthorityService(BaseService):
@@ -14,8 +14,14 @@ class DirectDebitAuthorityService(BaseService):
         )
         return DirectDebitAuthority(**response["direct_debit_authorities"])
 
-    def list(self, *args, **kwargs):
-        response = self._execute(DirectDebitAuthorityService.GET, self.endpoint)
+    def list(self, account_id, **kwargs):
+        filters = DirectDebitAuthorityFilters(account_id=account_id, **kwargs).dict(exclude_none=True)
+
+        endpoint = self.endpoint
+        if filters:
+            endpoint = self.append_query_params(endpoint, filters)
+
+        response = self._execute(DirectDebitAuthorityService.GET, endpoint)
         return list(map(lambda x: DirectDebitAuthority(**x), response.get("direct_debit_authorities", [])))
 
     def create(self, **kwargs):
