@@ -12,7 +12,7 @@ class TransactionService(BaseService):
         response = self._execute(
             TransactionService.GET, f"{self.endpoint}/{transaction_id}", url=self.beta_url
         )
-        return Transaction(**response)
+        return Transaction(**response["transactions"])
 
     def list(self):
         response = self._execute(TransactionService.GET, f"{self.endpoint}", url=self.beta_url)
