@@ -154,8 +154,8 @@ class Transaction(BaseModel):
     user_id: str
     user_name: str
     account_id: str
-    item_name: str
-    dynamic_descriptor: str
+    item_name: Optional[str]
+    dynamic_descriptor: Optional[str]
     amount: int
     currency: str
     debit_credit: str
